@@ -62,7 +62,7 @@ sub new_from_context {
   # Run the Build.PL
   $package->run_perl_script('Build.PL');
   my $self = $package->resume;
-  $self->merge_args(%args);
+  $self->merge_args(undef, %args);
   return $self;
 }
 
@@ -1143,7 +1143,7 @@ sub read_args {
     $args{$_} ||= [];
     $args{$_} = [ $args{$_} ] unless ref $args{$_};
     foreach my $arg ( @{$args{$_}} ) {
-      $arg =~ /(\w+)=(.+)/
+      $arg =~ /(\w+)=(.*)/
 	or die "Malformed '$_' argument: '$arg' should be something like 'foo=bar'";
       $hash{$1} = $2;
     }
